@@ -2,10 +2,13 @@ from .database.database import PostgresAuthData
 from .database.database import DataBase
 from .class_models.table import Table
 from .rooms.room_class import Rooms
+from .rooms.container import RoomsContainer
+from .utils.arguments_container import ArgumentsContainer
 
 __all__ = [
     "PostgresAuthData",
     "DataBase",
     "Table",
     "Rooms",
-]
\ No newline at end of file
+    "RoomsContainer"
+]
