@@ -5,5 +5,6 @@ from tgusers.database.database import DataBase
 
 class Tables:
     def __init__(self, db: DataBase):
-        self.users      = Users("Users", db)
-        self.messages   = Messages("Messages", db)
\ No newline at end of file
+        self._users      = Users("Users", db)
+        self._messages   = Messages("Messages", db)
+
