@@ -1,7 +1,7 @@
 import tgusers
 
 from dataclasses import dataclass
-
+from aiogram import types
 
 @dataclass
 class User:
@@ -43,11 +43,29 @@ class Users(tgusers.Table):
         """
         return self.db.request(sql, (message.chat.id,))[0].get("room")
 
+    def get_user_lang(self, message: types.Message = None, user_id: int = None):
+        if not user_id:
+            user_id = message.chat.id
+        sql = """
+                    SELECT language
+                    FROM "Users"
+                    WHERE telegram_id = %s;
+        """
+        return self.db.request(sql, (user_id,))[0].get("language")
+
+    def set_user_lang(self, language: str, message: types.Message = None, user_id: int = None):
+        if not user_id:
+            user_id = message.chat.id
+        sql = """   UPDATE "Users" 
+                    SET language = %s
+                    WHERE telegram_id = %s;"""
+        self.db.request(sql, (language, user_id,))
+        self.db.commit()
+
     def check_user_for_registration(self, message=None, telegram_id: int = None):
         if message:
             telegram_id = message.chat.id
-        sql = """
-                    SELECT id
+        sql = """   SELECT id
                     FROM "Users"
                     WHERE telegram_id = %s;
                 """
@@ -103,14 +121,14 @@ class Users(tgusers.Table):
 
     def add(self, user: User):
         sql = """   INSERT INTO "Users" (telegram_id, user_name, language, role, room)
-                    VALUES (%s, %s, %s, %s, %s, %s, %s, %s)
+                    VALUES (%s, %s, %s, %s, %s)
                     RETURNING id;
         """
         response = self.db.request(sql, (
             user.telegram_id, user.user_name, user.language,
             user.role, user.room))
         self.db.commit()
-        return response
+        return response[0]
 
     def get_users_ids(self):
         sql =   """
